/**
 * Copyright (c) 2008-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.registry.core.factory;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.ow2.petals.registry.api.config.Configuration;
import org.ow2.petals.registry.api.context.Context;
import org.ow2.petals.registry.api.exception.RegistryException;
import org.ow2.petals.registry.api.repository.Repository;
import org.ow2.petals.registry.api.util.Assert;
import org.ow2.petals.registry.api.util.Loader;

/**
 * @author Christophe HAMERLING - EBM WebSourcing
 */
public class RepositoryFactory {

    /**
     * The class logger
     */
    private static Log log = LogFactory.getLog(RepositoryFactory.class);

    /**
     * Creates a new instance of RepositoryFactory
     */
    private RepositoryFactory() {
    }

    /**
     * Load a repository
     * 
     * @param name
     *            the repository name
     * @param config
     *            the registry configuration
     * @return
     * @throws RegistryException
     */
    public static Repository load(Configuration config) throws RegistryException {
        Assert.notNull(config);
        Assert.notNull(config.getName());
        
        String name = config.getName();
        
        Context context = Context.getContext(name);
        if (context == null) {
            context = new Context(config);
            Context.store(context);
        }

        if (log.isDebugEnabled()) {
            log.debug("Loading repository");
        }
        Repository r = Loader.loadRepository(config.getRepositoryClassName());
        Assert.notNull(r);
        return r;
    }

}
