/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.registry.core.transport.cxf;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.cxf.endpoint.Server;
import org.apache.cxf.jaxws.JaxWsServerFactoryBean;
import org.ow2.petals.registry.api.manager.IncomingManager;
import org.ow2.petals.registry.api.transport.MessageReceiver;
import org.ow2.petals.registry.api.ws.Constants;
import org.ow2.petals.registry.api.ws.service.RegistryService;
import org.ow2.petals.registry.core.ws.service.RegistryServiceImpl;

/**
 * @author Christophe HAMERLING - EBM WebSourcing
 */
public class CXFMessageReceiver implements MessageReceiver {

    private Server server;

    private IncomingManager localManager;

    private String address;

    private static Log logger = LogFactory.getLog(CXFMessageReceiver.class);

    public CXFMessageReceiver() {
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * org.ow2.petals.registry.api.transport.MessageReceiver#startReceiving()
     */
    public void startReceiving() {
        address = getAddress();
        logger.debug("Start receiving on " + address);
        JaxWsServerFactoryBean svrFactory = new JaxWsServerFactoryBean();
        RegistryService service = new RegistryServiceImpl(this.localManager);
        svrFactory.setAddress(address);
        svrFactory.setServiceBean(service);
        server = svrFactory.create();
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * org.ow2.petals.registry.api.transport.MessageReceiver#stopReceiving()
     */
    public void stopReceiving() {
        logger.debug("Stop receiving on " + address);
        server.stop();
    }

    public IncomingManager getLocalManager() {
        return this.localManager;
    }

    public void setLocalManager(IncomingManager localManager) {
        this.localManager = localManager;
    }

    protected String getAddress() {
        // TODO : Get it from configuration
        return localManager.getLocalRegistry().getContext().getConfiguration()
                .getMessageReceiverURL()
                + Constants.REGISTRY_SERVICE;
    }
}
